﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Collections.ObjectModel; 
using System.ComponentModel;

namespace SilverlightApplication1
{
    public class CategoryDataCollection : ObservableCollection<CategoryDataPoint>
    {
        public CategoryDataCollection()
        {
            _title = "";
        }
        private string _title;
        public string Title
        {
            get { return _title; }
            set
            {
                if (_title.Equals(value)) return;
                _title = value;
                OnPropertyChanged(new PropertyChangedEventArgs("Title"));
            }
        }
        private bool _visible;
        public bool Visible
        {
            get { return _visible; }
            set 
            { 
                if (_visible == value) return; 
                _visible = value; 
                OnPropertyChanged(new PropertyChangedEventArgs("Visible")); 
            }
        }
    }
 
    public class CategoryDataPoint : INotifyPropertyChanged
    {
        public CategoryDataPoint() { }
        public CategoryDataPoint(double value, string cat, string label)
        {
            this.Value = value;
            this.Category = cat;
            this.Label = label;
        }
        public CategoryDataPoint(CategoryDataPoint dataPoint)
        {
            this.Index = dataPoint.Index;
            this.Category = dataPoint.Category;
            this.Value = dataPoint.Value;
            this.Date = dataPoint.Date;
            this.High = dataPoint.High;
            this.Low = dataPoint.Low;
        }
        public double Change
        {
            get { return High - Low; }
        }
        public double ChangePerCent
        {
            get { return (Change / High) * 100; }
        }
        private double _index;
        public double Index
        {
            get { return _index; }
            set { if (_index == value) return; _index = value; NotifyPropertyChanged("Index"); }
        }
        private double _value;
        public double Value
        {
            get { return _value; }
            set { if (_value == value) return; _value = value; NotifyPropertyChanged("Value"); }
        }
        private double _high;
        public double High
        {
            get { return _high; }
            set { if (_high == value) return; _high = value; NotifyPropertyChanged("High"); }
        }
        private double _low;
        public double Low
        {
            get { return _low; }
            set { if (_low == value) return; _low = value; NotifyPropertyChanged("Low"); }
        }
        private string _category;
        public string Category
        {
            get { return _category; }
            set { if (_category == value) return; _category = value; NotifyPropertyChanged("Category"); }
        }
 
        private string _label;
        public string Label
        {
            get { return _label; }
            set { if (_label == value) return; _label = value; NotifyPropertyChanged("Label"); }
        }
 
        private DateTime _date;
        public DateTime Date
        {
            get { return _date; }
            set { if (_date == value) return; _date = value; NotifyPropertyChanged("Date"); }
        }
        public new string ToString()
        {
            return String.Format("Category {0}, Value {1}", Category, Value);
        }
 
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
    }
 
    //public abstract class ObservableModel : INotifyPropertyChanged
    //{
    //    #region INotifyPropertyChanged
    //    public event PropertyChangedEventHandler PropertyChanged;
    //    protected void OnPropertyChanged(string propertyName)
    //    {
    //        if (this.PropertyChanged != null)
    //            this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
    //    }
 
    //    #endregion
    //}
 
}
